package de.hft.stuttgart.citydoctor2.webservice.endpoints;

import javax.persistence.EntityManager;
import javax.servlet.http.HttpServletRequest;
import javax.ws.rs.POST;
import javax.ws.rs.Path;
import javax.ws.rs.core.Context;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.Response.Status;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import de.hft.stuttgart.citydoctor2.webservice.AuthenticationException;
import de.hft.stuttgart.citydoctor2.webservice.utils.AuthenticationUtils;
import de.hft.stuttgart.citydoctor2.webservice.utils.HibernateUtils;

@Path("logout")
public class LogoutEndpoint {
	
	private static final Logger logger = LogManager.getLogger(LogoutEndpoint.class);

	@POST
	public Response logout(@Context HttpServletRequest request) {
		EntityManager manager = null;
		try {
			manager = HibernateUtils.createManager();
			AuthenticationUtils.removeTokenFromUser(request, manager);
			return Response.ok().build();
		} catch (AuthenticationException e) {
			logger.trace(AuthenticationUtils.AUTHENTICATION_DENIED, request.getRemoteAddr(), e);
			return Response.status(Status.FORBIDDEN).build();
		} catch (Exception e) {
			logger.fatal("Error while logging out unknown user");
			logger.catching(e);
			return Response.serverError().build();
		} finally {
			if (manager != null) {
				manager.close();
			}
		}
	}

}
